Kazoo
=====

[![Build Status](https://travis-ci.org/python-zk/kazoo.svg?branch=master)](https://travis-ci.org/python-zk/kazoo)
[![Latest Version](https://img.shields.io/pypi/v/kazoo.svg)](https://pypi.org/project/kazoo/)
[![Reviewed by Hound](https://img.shields.io/badge/Reviewed_by-Hound-8E64B0.svg)](https://houndci.com)

`kazoo` implements a higher level API to [Apache
Zookeeper](http://zookeeper.apache.org/) for Python clients.

See [the full docs](http://kazoo.rtfd.org/) for more information.

License
-------

`kazoo` is offered under the Apache License 2.0.

Authors
-------

`kazoo` started under the [Nimbus
Project](http://www.nimbusproject.org/) and through collaboration with
the open-source community has been merged with code from
[Mozilla](http://www.mozilla.org/) and the [Zope
Corporation](http://zope.com/). It has since gathered an active
community of over fifty contributors.
